#
# spec file for package mtools
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           mtools
BuildRequires:  autoconf
BuildRequires:  libpng
%if %suse_version > 1220
BuildRequires:  makeinfo
BuildRequires:  texinfo
%else
BuildRequires:  texlive-latex
%endif
BuildRequires:  xorg-x11
BuildRequires:  xorg-x11-devel
Version:        4.0.18
Release:        8.13
Url:            http://mtools.linux.lu/
Summary:        Access Files on an MS-DOS File System
License:        GPL-3.0+
Group:          System/Filesystems
Source:         http://ftp.gnu.org/gnu/mtools/%{name}-%{version}.tar.bz2
Patch0:         %{name}-%{version}-conf.diff
Patch1:         %{name}-%{version}-autoconf.diff
Patch3:         %{name}-%{version}-aliasing.diff
Patch4:         %{name}-%{version}-fat-bits.diff
Patch5:         %{name}-%{version}-prototypes.diff
Requires:       glibc-locale
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Mtools allows uncomplicated access to an MS-DOS file system on disk
without mounting it. It includes commands for working with MS-DOS
files: mdir, mcd, mcopy, and mformat.

XDF support for OS/2 is also provided.

%package floppyd
Summary:        Floppy daemon for remote access to floppy drive
License:        GPL-3.0+
Group:          System/Filesystems

%description floppyd
Floppyd is used as a server to grant access  to  the  floppy  drive  to
clients  running on a remote machine, just as an X server grants access
to the display to remote clients.

%package doc
Summary:        Access Files on an MS-DOS File System
License:        GPL-3.0+ and GFDL-1.3
Group:          System/Filesystems
Requires:       %{name} = %{version}

%description doc
Mtools allows uncomplicated access to an MS-DOS file system on disk
without mounting it. It includes commands for working with MS-DOS
files: mdir, mcd, mcopy, and mformat.

XDF support for OS/2 is also provided.

%prep
%setup -q
%patch0
%patch1
%patch3
%patch4
%patch5

%build
autoconf --force
export CC=gcc
export INSTALL_PROGRAM="install"
%configure \
    --includedir=/usr/src/linux/include
make all dvi info

%install
install -d -m 755 $RPM_BUILD_ROOT%{_sysconfdir}
make install DESTDIR=$RPM_BUILD_ROOT
cp -p mtools.conf $RPM_BUILD_ROOT%{_sysconfdir}

%post
%install_info --info-dir=%{_infodir} %{_infodir}/mtools.info.gz

%postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/mtools.info.gz

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%config %{_sysconfdir}/mtools.conf
%doc Release.notes NEWS COPYING README*
%doc %{_mandir}/man?*/*
%exclude %{_mandir}/man?*/f*
%doc %{_infodir}/mtools.info*
%{_bindir}/*
%exclude %{_bindir}/f*

%files floppyd
%defattr(-,root,root)
%doc %{_mandir}/man?*/f*
%{_bindir}/f*

%files doc
%defattr(-,root,root)
%doc *.dvi

%changelog
* Mon Nov 30 2015 pgajdos@suse.com
- require glibc-locale [bnc#957007]
* Tue Apr 16 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Tue Mar 26 2013 pgajdos@suse.com
- updated to 4.0.18:
  * Fix for names of iconv encodings on AIX
  * Fix mt_size_t on NetBSD
  * Fixed compilation on Mingw
  * Fixed doc (especially mformat)
  * Fix mformat'ing of FAT12 filesystems with huge cluster sizes
  * Minfo prints image file name in mformat command line if an image
    file name was given
  * Always generate gzip-compressed RPMs, in order to remain
    compatible with older distributions
  * Fixed buffer overflow with drive letter in mclasserase
- extended fat-bits.patch: add fat_bits parameter again to fat_read()
  and old_fat_read(); it is candidate to drop though
* Tue Jul 24 2012 werner@suse.de
- Make it build with texinfo/makeinfo split
* Mon Jul 23 2012 coolo@suse.com
- add texinfo as buildrequire
* Mon Jul  2 2012 cfarrell@suse.com
- license update: GPL-3.0+
  mtools is GPL-3.0+ licensed, not GPL-2.0+
* Wed Dec 21 2011 coolo@suse.com
- add autoconf as buildrequire to avoid implicit dependency
* Wed Dec 21 2011 coolo@suse.com
- remove call to suse_update_config (very old work around)
* Thu Jun 30 2011 pgajdos@novell.com
- updated to 4.0.17:
  * mbadblocks now takes a list of bad blocks (either as sectors
    or as clusters)
  * mbadblocks now is able to do write scanning for bad blocks
  * mshowfat can show cluster of specific offset
  * Enable mtools to deal with very small sector sizes...
  * Fixed encoding of all-lowercase names (no need to mangle
    these)
  * Consider every directory entry after an ENDMARK (0x00) to be deleted
  * After writing a new entry at end of a directory, be sure to also add
    an ENDMARK (0x00)
  * Deal with possibility of a NULL pointer being returned by
    localtime during timestamp conversion
* Mon May 23 2011 pgajdos@novell.com
- updated to 4.0.16:
  * fixed formatting of fat_size_calculation.tex document
  * Make it clear that label is limited to 13 characters
  * Fixed typo in initialization of FAT32 info sector
- remove invalid-memory.diff
* Thu Mar 17 2011 pgajdos@suse.cz
- fixed crash caused with access of invalid memory [bnc#679459]
* Tue Nov 16 2010 pgajdos@suse.cz
- updated to version 4.0.15:
  * Added missing -i option to mshortname
  * New mshortname command
  * Fix floppyd for disks bigger than 2 Gig
  * Remove obsolete -z flag
  * Remove now unsupported AC_USE_SYSTEM_EXTENSIONS
  * Fixed output formatting of mdir if MTOOLS_DOTTED_DIR is set
  * Mformat now correctly writes backup boot sector
  * Fixed signedness of serial number in mlabel
  * Fixed buffer size problem in mlabel
  * Make mlabel write backup boot sector if FAT32
  * Catch situation where both clear and new label are given to mlabel
  * Quote filename parameters to scripts
  * Mformat: Close file descriptor for boot sector
  * Added lzip support to scripts/uz
  * Added Tot_sectors option to mformat
  * Fixed hidden sector handling in mformat
  * Minfo generates mformat command lines containing new -T option
  * Mlabel prints error if label too long
- removed upstreamed patches:
  * script.diff
  * file_close.diff
  * initialize.diff
* Tue Jun 29 2010 pgajdos@suse.cz
- fixed initialization in mlabel.c [bnc#618326]
* Mon Mar  1 2010 pgajdos@suse.cz
- updated to 4.0.13 (upstreamed debian patches)
* Sun Dec  6 2009 meissner@suse.de
- uppercase summary of -floppyd
* Tue Nov 24 2009 pgajdos@suse.cz
- updated to 4.0.12 (see NEWS)
  - removed upstreamed help-flag.diff and overflow.diff
* Fri Oct 23 2009 pgajdos@suse.cz
- fixed wrong -h flag [bnc#548449]
  * help-flag.diff
* Tue Sep 15 2009 pgajdos@suse.cz
- added missing call to close [bnc#535718]
* Wed Apr 15 2009 ro@suse.de
- buildfix: refresh patches
* Mon Mar 16 2009 pgajdos@suse.cz
- updated to 4.0.10 (see NEWS)
  * adjusted overflow.patch
- splitted out doc package
* Wed Jan 21 2009 schwab@suse.de
- Fix buffer overflows.
* Tue Jan 13 2009 pgajdos@suse.cz
- updated to 4.0.1
  * unicode support
  * use transliteration to represent characters which don't exist in
    target set
  * Offset for -i-specified image files
* Tue Jun  5 2007 prusnak@suse.cz
- updated to 3.9.11
  * fixed reading of boot sector
  * fixed mlabel on read-only disks
  * added sizecode printing on minfo
  * support for config parameters after -i file
- drop obsolete patches:
  * memset.diff (included in update)
* Sun Apr 22 2007 ro@suse.de
- use texlive for building
* Mon Feb  6 2006 mjancar@suse.cz
- bransh mtools-floppy to prevent dependecy on X11 (#146102)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Nov 18 2005 meissner@suse.de
- fixed swapped memset() arguments.
* Wed Aug  3 2005 mjancar@suse.cz
- update to 3.9.10
- drop obsolete patches:
  * mtools-3.9.9-20030718.diff.gz
  * mtools-execNULL.diff
- split mtools-3.9.9.diff into:
  * mtools-3.9.10-autoconf.diff
  * mtools-3.9.10-conf.diff
  * mtools-3.9.10-prototypes.diff
* Tue Apr  5 2005 mmj@suse.de
- execl(..., 0) --> execl(..., NULL);
* Sun Feb 13 2005 ro@suse.de
- added libpng to nfb (for tetex)
* Mon Jan 24 2005 meissner@suse.de
- fixed one execl call, fixed one lvalue cast.
* Sun Jun 13 2004 schwab@suse.de
- Allow overriding fat bits.
* Thu Apr 22 2004 tcrhak@suse.cz
- strict aliasing fix
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Thu Jul 31 2003 uli@suse.de
- fixed to build on 64-bit archs
* Tue Jul 29 2003 tcrhak@suse.cz
- update to version 3.9.9
* Thu Dec 19 2002 tcrhak@suse.cz
- updated patch to mtools-3.9.8-20021118.diff.bz2
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Mon Dec  3 2001 tcrhak@suse.cz
- updated patch to mtools-3.9.8-20011127.diff.bz2
* Mon Oct  1 2001 schwab@suse.de
- Fix quoting in shell scripts.
* Wed Jun 13 2001 adostal@suse.cz
- upgrade to 3.9.8
* Tue Jun 12 2001 schwab@suse.de
- Fix configure script.
* Tue Apr  3 2001 cihlar@suse.cz
- updated patchkit
* Mon Mar 26 2001 cihlar@suse.cz
- updated patchkit
* Fri Feb  9 2001 cihlar@suse.cz
- removed lx_suse from neededforbuild
- do not include kernel headers
* Thu Feb  8 2001 cihlar@suse.cz
- fixed to compile
* Tue Jan  9 2001 cihlar@suse.cz
- updated patchkit
* Tue Dec  5 2000 cihlar@suse.cz
- updated patchkit
* Wed Nov 22 2000 cihlar@suse.cz
- updated patchkit
* Thu Nov  9 2000 cihlar@suse.cz
- improved BuildRoot
- fixed file list
- bzipped sources
* Fri Oct 20 2000 cihlar@suse.cz
- updated patchkit
* Fri Sep  8 2000 schwab@suse.de
- Fix typo in configure script and pass -D_GNU_SOURCE to compiler
  (obsoletes last change for alpha)
- Add suse_update_config.
* Mon Aug 28 2000 ro@suse.de
- fixed to compile on alpha
* Wed Aug 16 2000 cihlar@suse.cz
- updated patchkit
* Sat Jun 24 2000 kasal@suse.de
- updated patchkit
* Mon Jun 19 2000 kasal@suse.de
- upgrade to 3.9.7
* Wed Apr 26 2000 kasal@suse.de
- upgrade to mtools-3.9.6-20000417.diff.gz
* Wed Apr 12 2000 kasal@suse.cz
- upgrade to mtools-3.9.6-20000410.diff.gz
* Mon Mar 27 2000 kasal@suse.cz
- added patch mtools-3.9.6-20000320b.diff.gz (fixes BUG# 2590)
* Wed Mar  1 2000 kasal@suse.de
- moved manpages to %%{_mandir}
- added buildroot and shortened %%filelist
- added mtools.info* files (and texinfo to #neededforbuild)
* Mon Sep 20 1999 uli@suse.de
- fixed #include conflict showing up on PPC
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Fri Jul  9 1999 uli@suse.de
- update -> 3.9.6
* Tue Mar 23 1999 ro@suse.de
- don't use -O4 ; strip binaries
* Mon Mar 22 1999 ro@suse.de
- update to 3.9.4
* Fri Dec 11 1998 rj@suse.de
- parameters in mtools.conf for 1,44MB disks hardcoded
* Wed Oct 28 1998 ro@suse.de
- respect change in 2.1.126 SCSI_DISK_MAJOR
* Sun Jul 26 1998 bs@suse.de
- used old config file again.
* Tue Jul 21 1998 bs@suse.de
- update to version 3.9.1
* Tue Feb 24 1998 ro@suse.de
- removed man-pages mread and mwrite
  (contain no information, just texinfos blabla)
* Thu Jun 12 1997 rj@suse.de
- modification in /etc/mtools.conf
* Fri Apr 18 1997 rj@suse.de
- new version 3.6
* Mon Mar  3 1997 rj@suse.de
- new version 3.3
* Tue Feb 25 1997 rj@suse.de
- new version 3.2
  - /usr/doc/packages/mtools now included
  - xdf Support
